@@ -1,13 +1,9 @@
 #include <afs/param.h>
 #include <afs/stds.h>
 
-#ifndef DJGPP
 #include <windows.h>
 #include <winreg.h>
 #include <winsock2.h>
-#else
-#include <netdb.h>
-#endif /* !DJGPP */
 #include <stdlib.h>
 #include <malloc.h>
 #include <string.h>
@@ -22,26 +18,23 @@
 
 extern void afsi_log(char *pattern, ...);
 
-int cm_noLocalMountPoints;
+static int cm_noLocalMountPoints;
 char * cm_FakeRootDir = NULL;
 int cm_fakeDirSize = 0;
 int cm_fakeDirCallback=0;
 int cm_fakeGettingCallback=0;
-cm_localMountPoint_t* cm_localMountPoints;
+static cm_localMountPoint_t* cm_localMountPoints;
 osi_mutex_t cm_Freelance_Lock;
-int cm_localMountPointChangeFlag = 0;
+static int cm_localMountPointChangeFlag = 0;
 int cm_freelanceEnabled = 1;
 time_t FakeFreelanceModTime = 0x3b49f6e2;
 
 static int freelance_ShutdownFlag = 0;
-#if !defined(DJGPP)
 static HANDLE hFreelanceChangeEvent = 0;
 static HANDLE hFreelanceSymlinkChangeEvent = 0;
-#endif
 
 void cm_InitFakeRootDir();
 
-#if !defined(DJGPP)
 void cm_FreelanceChangeNotifier(void * parmp) {
     HKEY   hkFreelance = 0;
 
@@ -131,32 +124,23 @@ void cm_FreelanceSymlinkChangeNotifier(void * parmp) {
         }
     }
 }
-#endif
 
 void                                          
 cm_FreelanceShutdown(void)                    
 {                                             
     freelance_ShutdownFlag = 1;               
-#if !defined(DJGPP)                           
     if (hFreelanceChangeEvent != 0)           
         thrd_SetEvent(hFreelanceChangeEvent); 
     if (hFreelanceSymlinkChangeEvent != 0)           
         thrd_SetEvent(hFreelanceSymlinkChangeEvent); 
-#endif                                        
 }                                             
 
 void cm_InitFreelance() {
-#if !defined(DJGPP)
     thread_t phandle;
     int lpid;
-#endif
 
-    lock_InitializeMutex(&cm_Freelance_Lock, "Freelance Lock");
+    lock_InitializeMutex(&cm_Freelance_Lock, "Freelance Lock", LOCK_HIERARCHY_FREELANCE_GLOBAL);
 
-    // make sure we sync the data version to the cached root scache_t                  
-    if (cm_data.rootSCachep && cm_data.rootSCachep->fid.cell == AFS_FAKE_ROOT_CELL_ID) 
-        cm_data.fakeDirVersion = cm_data.rootSCachep->dataVersion;                          
-                                                                                      
     // yj: first we make a call to cm_initLocalMountPoints
     // to read all the local mount points from the registry
     cm_InitLocalMountPoints();
@@ -166,7 +150,6 @@ void cm_InitFreelance() {
     cm_InitFakeRootDir();
     // --- end of yj code
 
-#if !defined(DJGPP)
     /* Start the registry monitor */
     phandle = thrd_Create(NULL, 65536, (ThreadFunc) cm_FreelanceChangeNotifier,
                           NULL, 0, &lpid, "cm_FreelanceChangeNotifier");
@@ -177,7 +160,6 @@ void cm_InitFreelance() {
                           NULL, 0, &lpid, "cm_FreelanceSymlinkChangeNotifier");
     osi_assertx(phandle != NULL, "cm_FreelanceSymlinkChangeNotifier thread create failure");
     thrd_CloseHandle(phandle);
-#endif
 }
 
 /* yj: Initialization of the fake root directory */
@@ -271,7 +253,6 @@ void cm_InitFakeRootDir() {
     curChunk = 13;
 
     // stick the first 2 entries "." and ".." in
-    fakeEntry.fid.unique = htonl(1);
     fakeEntry.fid.vnode = htonl(1);
     strcpy(fakeEntry.name, ".");
     currentPos = cm_FakeRootDir + curPage * CM_DIR_PAGESIZE + curChunk * CM_DIR_CHUNKSIZE;
@@ -293,7 +274,9 @@ void cm_InitFakeRootDir() {
     {       
 
         noChunks = cm_NameEntries((cm_localMountPoints+curDirEntry)->namep, 0);
-        fakeEntry.fid.vnode = htonl(curDirEntry + 2);
+        /* enforce the rule that only directories have odd vnode values */
+        fakeEntry.fid.vnode = htonl((curDirEntry + 1) * 2);
+        fakeEntry.fid.unique = htonl(curDirEntry + 1);
         currentPos = cm_FakeRootDir + curPage * CM_DIR_PAGESIZE + curChunk * CM_DIR_CHUNKSIZE;
 
         memcpy(currentPos, &fakeEntry, CM_DIR_CHUNKSIZE);
@@ -335,7 +318,9 @@ void cm_InitFakeRootDir() {
             // add an entry to this page
 
             noChunks = cm_NameEntries((cm_localMountPoints+curDirEntry)->namep, 0);
-            fakeEntry.fid.vnode=htonl(curDirEntry+2);
+            /* enforce the rule that only directories have odd vnode values */
+            fakeEntry.fid.vnode = htonl((curDirEntry + 1) * 2);
+            fakeEntry.fid.unique = htonl(curDirEntry + 1);
             currentPos = cm_FakeRootDir + curPage * CM_DIR_PAGESIZE + curChunk * CM_DIR_CHUNKSIZE;
             memcpy(currentPos, &fakeEntry, CM_DIR_CHUNKSIZE);
             strcpy(currentPos + 12, (cm_localMountPoints+curDirEntry)->namep);
@@ -400,43 +385,44 @@ int cm_reInitLocalMountPoints() {
 
     osi_Log0(afsd_logp,"Invalidating local mount point scp...  ");
 
-    cm_SetFid(&aFid, AFS_FAKE_ROOT_CELL_ID, AFS_FAKE_ROOT_VOL_ID, 1, 2);
-
     lock_ObtainWrite(&cm_scacheLock);
     lock_ObtainMutex(&cm_Freelance_Lock);  /* always scache then freelance lock */
-    for (i=0; i<cm_noLocalMountPoints; i++) {
+    for (i=0; i<=cm_noLocalMountPoints; i++) {
+        if (i == 0)
+            cm_SetFid(&aFid, AFS_FAKE_ROOT_CELL_ID, AFS_FAKE_ROOT_VOL_ID, 1, 1);
+        else
+            cm_SetFid(&aFid, AFS_FAKE_ROOT_CELL_ID, AFS_FAKE_ROOT_VOL_ID, i*2, i);
         hash = CM_SCACHE_HASH(&aFid);
         for (scp=cm_data.scacheHashTablep[hash]; scp; scp=scp->nextp) {
-            if (scp->fid.volume == aFid.volume &&
-                 scp->fid.vnode == aFid.vnode &&
-                 scp->fid.unique == aFid.unique 
-                 ) {
-
+            if (scp != cm_data.rootSCachep && cm_FidCmp(&scp->fid, &aFid) == 0) {
                 // mark the scp to be reused
                 cm_HoldSCacheNoLock(scp);
+                lock_ReleaseMutex(&cm_Freelance_Lock);
                 lock_ReleaseWrite(&cm_scacheLock);
                 lock_ObtainWrite(&scp->rw);
                 cm_DiscardSCache(scp);
-                lock_ReleaseWrite(&scp->rw);
-                cm_CallbackNotifyChange(scp);
-                lock_ObtainWrite(&cm_scacheLock);
-                cm_ReleaseSCacheNoLock(scp);
 
                 // take the scp out of the hash
+                lock_ObtainWrite(&cm_scacheLock);
                 for (lscpp = &cm_data.scacheHashTablep[hash], tscp = cm_data.scacheHashTablep[hash]; 
                      tscp; 
                      lscpp = &tscp->nextp, tscp = tscp->nextp) {
                     if (tscp == scp) {
                         *lscpp = scp->nextp;
-			lock_ObtainWrite(&scp->rw);
+                        scp->nextp = NULL;
                         scp->flags &= ~CM_SCACHEFLAG_INHASH;
-			lock_ReleaseWrite(&scp->rw);
                         break;
                     }
                 }
+
+                lock_ReleaseWrite(&scp->rw);
+                lock_ReleaseWrite(&cm_scacheLock);
+                cm_CallbackNotifyChange(scp);
+                lock_ObtainWrite(&cm_scacheLock);
+                cm_ReleaseSCacheNoLock(scp);
+                lock_ObtainMutex(&cm_Freelance_Lock);
             }
         }
-        cm_SetFid(&aFid, AFS_FAKE_ROOT_CELL_ID, AFS_FAKE_ROOT_VOL_ID, aFid.vnode + 1, 2);
     }
     lock_ReleaseWrite(&cm_scacheLock);
     osi_Log0(afsd_logp,"\tall old scp cleared!");
@@ -477,16 +463,13 @@ long cm_InitLocalMountPoints() {
     char hdir[260];
     long code;
     char rootCellName[256];
-#if !defined(DJGPP)
     HKEY hkFreelance = 0, hkFreelanceSymlinks = 0;
     DWORD dwType, dwSize;
     DWORD dwMountPoints = 0;
     DWORD dwIndex;
     DWORD dwSymlinks = 0;
     FILETIME ftLastWriteTime;
-#endif
 
-#if !defined(DJGPP)
     if (RegOpenKeyEx( HKEY_LOCAL_MACHINE, 
                       AFSREG_CLT_OPENAFS_SUBKEY "\\Freelance",
                       0,
@@ -507,7 +490,7 @@ long cm_InitLocalMountPoints() {
                          &ftLastWriteTime /* lpftLastWriteTime */
                          );
 
-        smb_UnixTimeFromLargeSearchTime(&FakeFreelanceModTime, &ftLastWriteTime);
+        cm_UnixTimeFromLargeSearchTime(&FakeFreelanceModTime, &ftLastWriteTime);
 
         if ( dwMountPoints == 0 ) {
             rootCellName[0] = '.';
@@ -678,7 +661,6 @@ long cm_InitLocalMountPoints() {
         RegCloseKey(hkFreelance);
         return 0;
     }
-#endif
 
     /* What follows is the old code to read freelance mount points 
      * out of a text file modified to copy the data into the registry
@@ -695,7 +677,6 @@ long cm_InitLocalMountPoints() {
         fp = fopen(hdir, "r");
     }
 
-#if !defined(DJGPP)
     RegCreateKeyEx( HKEY_LOCAL_MACHINE, 
                     AFSREG_CLT_OPENAFS_SUBKEY "\\Freelance",
                     0,
@@ -706,12 +687,9 @@ long cm_InitLocalMountPoints() {
                     &hkFreelance,
                     NULL);
     dwIndex = 0;
-#endif
 
     if (!fp) {
-#if !defined(DJGPP)
         RegCloseKey(hkFreelance);
-#endif
         rootCellName[0] = '.';
       	code = cm_GetRootCellName(&rootCellName[1]);
         if (code == 0) {
@@ -768,7 +746,6 @@ long cm_InitLocalMountPoints() {
         if (t2)
             *(t2+1) = '\0';
 
-#if !defined(DJGPP)
         if ( hkFreelance ) {
             char szIndex[16];
             /* we are migrating to the registry */
@@ -777,7 +754,6 @@ long cm_InitLocalMountPoints() {
             dwSize = (DWORD)strlen(line) + 1;
             RegSetValueEx( hkFreelance, szIndex, 0, dwType, line, dwSize);
         }
-#endif 
 
         // line is not empty, so let's parse it
         t = strchr(line, '#');
@@ -804,12 +780,10 @@ long cm_InitLocalMountPoints() {
         aLocalMountPoint++;
     }
     fclose(fp);
-#if !defined(DJGPP)
     if ( hkFreelance ) {
         RegCloseKey(hkFreelance);
         DeleteFile(hdir);
     }
-#endif
     return 0;
 }
 
@@ -817,7 +791,6 @@ int cm_getNoLocalMountPoints() {
     return cm_noLocalMountPoints;
 }
 
-#if !defined(DJGPP)
 long cm_FreelanceMountPointExists(char * filename, int prefix_ok)
 {
     char* cp;
@@ -882,7 +855,7 @@ long cm_FreelanceMountPointExists(char * filename, int prefix_ok)
             memcpy(shortname, line, cp-line);
             shortname[cp-line]=0;
 
-            if (!stricmp(shortname, filename)) {
+            if (!cm_stricmp_utf8(shortname, filename)) {
                 found = 1;
                 break;
             }
@@ -965,7 +938,7 @@ long cm_FreelanceSymlinkExists(char * filename, int prefix_ok)
             memcpy(shortname, line, cp-line);
             shortname[cp-line]=0;
 
-            if (!stricmp(shortname, filename)) {
+            if (!cm_stricmp_utf8(shortname, filename)) {
                 found = 1;
                 break;
             }
@@ -977,22 +950,19 @@ long cm_FreelanceSymlinkExists(char * filename, int prefix_ok)
 
     return found;
 }
-#endif
 
 long cm_FreelanceAddMount(char *filename, char *cellname, char *volume, int rw, cm_fid_t *fidp)
 {
     FILE *fp;
     char hfile[260];
     char line[512];
-    char fullname[200];
+    char fullname[CELL_MAXNAMELEN];
     int n;
     int alias = 0;
-#if !defined(DJGPP)
     HKEY hkFreelance = 0;
     DWORD dwType, dwSize;
     DWORD dwMountPoints;
     DWORD dwIndex;
-#endif
 
     /* before adding, verify the cell name; if it is not a valid cell,
        don't add the mount point.
@@ -1015,18 +985,15 @@ long cm_FreelanceAddMount(char *filename, char *cellname, char *volume, int rw,
             return -1;
     }
 
-#if !defined(DJGPP)
     if ( cm_FreelanceMountPointExists(filename, 0) ||
          cm_FreelanceSymlinkExists(filename, 0) )
         return -1;
-#endif
     
     osi_Log1(afsd_logp,"Freelance Adding Mount for Cell: %s", 
               osi_LogSaveString(afsd_logp,cellname));
 
     lock_ObtainMutex(&cm_Freelance_Lock);
 
-#if !defined(DJGPP)
     if (RegOpenKeyEx( HKEY_LOCAL_MACHINE, 
                       AFSREG_CLT_OPENAFS_SUBKEY "\\Freelance",
                       0,
@@ -1081,7 +1048,6 @@ long cm_FreelanceAddMount(char *filename, char *cellname, char *volume, int rw,
         }
         RegCloseKey(hkFreelance);
     } else 
-#endif
     {
         cm_GetConfigDir(hfile, sizeof(hfile));
         strcat(hfile, AFS_FREELANCE_INI);
@@ -1100,12 +1066,33 @@ long cm_FreelanceAddMount(char *filename, char *cellname, char *volume, int rw,
             fprintf(fp, "%s#%s:%s\n", filename, fullname, volume);
         fclose(fp);
     }
+
+    /* Do this while we are holding the lock */
+    cm_data.fakeDirVersion++;
+    cm_localMountPointChangeFlag = 1;
     lock_ReleaseMutex(&cm_Freelance_Lock);
 
-    /* cm_reInitLocalMountPoints(); */
-    if (fidp)
-        cm_SetFid(fidp, fidp->cell, fidp->volume, cm_noLocalMountPoints + 1, 1);
-    cm_noteLocalMountPointChange();
+    if (fidp) {
+        cm_req_t req;
+        afs_uint32 code;
+        cm_scache_t *scp;
+        clientchar_t *cpath;
+
+        cm_InitReq(&req);
+
+        cpath = cm_FsStringToClientStringAlloc(filename, -1, NULL);        
+        if (!cpath)
+            return CM_ERROR_NOSUCHPATH;
+        code = cm_NameI(cm_data.rootSCachep, cpath,
+                        CM_FLAG_FOLLOW | CM_FLAG_CASEFOLD | CM_FLAG_DFS_REFERRAL,
+                        cm_rootUserp, NULL, &req, &scp);
+        free(cpath);
+        if (code)
+            return code;
+        *fidp = scp->fid;
+        cm_ReleaseSCache(scp);
+    }
+    
     return 0;
 }
 
@@ -1118,16 +1105,13 @@ long cm_FreelanceRemoveMount(char *toremove)
     char hfile[260], hfile2[260];
     FILE *fp1, *fp2;
     int found=0;
-#if !defined(DJGPP)
     HKEY hkFreelance = 0;
     DWORD dwType, dwSize;
     DWORD dwMountPoints;
     DWORD dwIndex;
-#endif
 
     lock_ObtainMutex(&cm_Freelance_Lock);
 
-#if !defined(DJGPP)
     if (RegOpenKeyEx( HKEY_LOCAL_MACHINE, 
                       AFSREG_CLT_OPENAFS_SUBKEY "\\Freelance",
                       0,
@@ -1163,12 +1147,12 @@ long cm_FreelanceRemoveMount(char *toremove)
 
             if (!strcmp(shortname, toremove)) {
                 RegDeleteValue( hkFreelance, szValueName );
+                found = 1;
                 break;
             }
         }
         RegCloseKey(hkFreelance);
     } else 
-#endif
     {
         cm_GetConfigDir(hfile, sizeof(hfile));
         strcat(hfile, AFS_FREELANCE_INI);
@@ -1205,29 +1189,30 @@ long cm_FreelanceRemoveMount(char *toremove)
 
         fclose(fp1);
         fclose(fp2);
-        if (!found)
-            return CM_ERROR_NOSUCHFILE;
+        if (found) {
+            unlink(hfile);
+            rename(hfile2, hfile);
+        }
+    }
 
-        unlink(hfile);
-        rename(hfile2, hfile);
+    if (found) {
+        /* Do this while we are holding the lock */
+        cm_data.fakeDirVersion++;
+        cm_localMountPointChangeFlag = 1;
     }
-    
     lock_ReleaseMutex(&cm_Freelance_Lock);
-    cm_noteLocalMountPointChange();
-    return 0;
+    return (found ? 0 : CM_ERROR_NOSUCHFILE);
 }
 
 long cm_FreelanceAddSymlink(char *filename, char *destination, cm_fid_t *fidp)
 {
     char line[512];
-    char fullname[200];
+    char fullname[CELL_MAXNAMELEN];
     int alias = 0;
-#if !defined(DJGPP)
     HKEY hkFreelanceSymlinks = 0;
     DWORD dwType, dwSize;
     DWORD dwSymlinks;
     DWORD dwIndex;
-#endif
 
     /* before adding, verify the filename.  If it is already in use, either as 
      * as mount point or a cellname, do not permit the creation of the symlink.
@@ -1242,23 +1227,20 @@ long cm_FreelanceAddSymlink(char *filename, char *destination, cm_fid_t *fidp)
     fullname[0] = '\0';
     if (filename[0] == '.') {
         cm_GetCell_Gen(&filename[1], fullname, CM_FLAG_CREATE);
-        if (stricmp(&filename[1],fullname) == 0)
+        if (cm_stricmp_utf8(&filename[1],fullname) == 0)
             return CM_ERROR_EXISTS;
     } else {
         cm_GetCell_Gen(filename, fullname, CM_FLAG_CREATE);
-        if (stricmp(filename,fullname) == 0)
+        if (cm_stricmp_utf8(filename,fullname) == 0)
             return CM_ERROR_EXISTS;
     }
 
-#if !defined(DJGPP)
     if ( cm_FreelanceMountPointExists(filename, 0) ||
          cm_FreelanceSymlinkExists(filename, 0) )
         return CM_ERROR_EXISTS;
-#endif
 
     lock_ObtainMutex(&cm_Freelance_Lock);
 
-#if !defined(DJGPP)
     if (RegCreateKeyEx( HKEY_LOCAL_MACHINE, 
                         AFSREG_CLT_OPENAFS_SUBKEY "\\Freelance\\Symlinks",
                         0,
@@ -1313,13 +1295,33 @@ long cm_FreelanceAddSymlink(char *filename, char *destination, cm_fid_t *fidp)
         }
         RegCloseKey(hkFreelanceSymlinks);
     } 
-#endif
+
+    /* Do this while we are holding the lock */
+    cm_data.fakeDirVersion++;
+    cm_localMountPointChangeFlag = 1;
     lock_ReleaseMutex(&cm_Freelance_Lock);
 
-    /* cm_reInitLocalMountPoints(); */
-    if (fidp)
-        cm_SetFid(fidp, fidp->cell, fidp->volume, cm_noLocalMountPoints + 1, 1);
-    cm_noteLocalMountPointChange();
+    if (fidp) {
+        cm_req_t req;
+        afs_uint32 code;
+        cm_scache_t *scp;
+        clientchar_t *cpath;
+
+        cm_InitReq(&req);
+
+        cpath = cm_FsStringToClientStringAlloc(filename, -1, NULL);        
+        if (!cpath)
+            return CM_ERROR_NOSUCHPATH;
+        code = cm_NameI(cm_data.rootSCachep, cpath,
+                        CM_FLAG_FOLLOW | CM_FLAG_CASEFOLD | CM_FLAG_DFS_REFERRAL,
+                        cm_rootUserp, NULL, &req, &scp);
+        free(cpath);
+        if (code)
+            return code;
+        *fidp = scp->fid;
+        cm_ReleaseSCache(scp);
+    }
+
     return 0;
 }
 
@@ -1329,16 +1331,13 @@ long cm_FreelanceRemoveSymlink(char *toremove)
     char line[512];
     char shortname[200];
     int found=0;
-#if !defined(DJGPP)
     HKEY hkFreelanceSymlinks = 0;
     DWORD dwType, dwSize;
     DWORD dwSymlinks;
     DWORD dwIndex;
-#endif
 
     lock_ObtainMutex(&cm_Freelance_Lock);
 
-#if !defined(DJGPP)
     if (RegOpenKeyEx( HKEY_LOCAL_MACHINE, 
                       AFSREG_CLT_OPENAFS_SUBKEY "\\Freelance\\Symlinks",
                       0,
@@ -1372,15 +1371,58 @@ long cm_FreelanceRemoveSymlink(char *toremove)
 
             if (!strcmp(shortname, toremove)) {
                 RegDeleteValue( hkFreelanceSymlinks, szValueName );
+                found = 1;
                 break;
             }
         }
         RegCloseKey(hkFreelanceSymlinks);
     }
-#endif
     
+    if (found) {
+        /* Do this while we are holding the lock */
+        cm_data.fakeDirVersion++;
+        cm_localMountPointChangeFlag = 1;
+    }
     lock_ReleaseMutex(&cm_Freelance_Lock);
-    cm_noteLocalMountPointChange();
+    return (found ? 0 : CM_ERROR_NOSUCHFILE);
+}
+
+long
+cm_FreelanceFetchMountPointString(cm_scache_t *scp)
+{
+    lock_ObtainMutex(&cm_Freelance_Lock);
+    if (!scp->mountPointStringp[0] && 
+        scp->fid.cell == AFS_FAKE_ROOT_CELL_ID &&
+        scp->fid.volume == AFS_FAKE_ROOT_VOL_ID && 
+        scp->fid.unique <= cm_noLocalMountPoints) {
+        strncpy(scp->mountPointStringp, cm_localMountPoints[scp->fid.unique-1].mountPointStringp, MOUNTPOINTLEN);
+        scp->mountPointStringp[MOUNTPOINTLEN-1] = 0;	/* null terminate */
+    }
+    lock_ReleaseMutex(&cm_Freelance_Lock);
+
+    return 0;
+}
+
+long 
+cm_FreelanceFetchFileType(cm_scache_t *scp)
+{
+    lock_ObtainMutex(&cm_Freelance_Lock);
+    if (scp->fid.cell == AFS_FAKE_ROOT_CELL_ID &&
+        scp->fid.volume == AFS_FAKE_ROOT_VOL_ID && 
+        scp->fid.unique <= cm_noLocalMountPoints) 
+    {
+        scp->fileType = cm_localMountPoints[scp->fid.unique-1].fileType;
+    
+        if ( scp->fileType == CM_SCACHETYPE_SYMLINK &&
+             !strnicmp(cm_localMountPoints[scp->fid.unique-1].mountPointStringp, "msdfs:", strlen("msdfs:")) )
+        {
+            scp->fileType = CM_SCACHETYPE_DFSLINK;
+        } 
+    } else {
+        scp->fileType = CM_SCACHETYPE_INVALID;
+    }
+    lock_ReleaseMutex(&cm_Freelance_Lock);
+
     return 0;
 }
 #endif /* AFS_FREELANCE_CLIENT */
