@@ -16,13 +16,7 @@
 #ifdef	AFS_AIX32_ENV
 #include <signal.h>
 #endif
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 #include <errno.h>
 
 #include <lock.h>
@@ -30,9 +24,7 @@
 
 #include <stdio.h>
 #include <pwd.h>
-#if 0
 #include <afs/com_err.h>
-#endif
 #include <afs/auth.h>
 #include <afs/afsutil.h>
 #include <afs/cellconfig.h>
@@ -50,12 +42,8 @@
 #define USING_HEIMDAL 1
 #endif
 
-#ifndef USING_HEIMDAL
-extern krb5_cc_ops krb5_mcc_ops;
-#endif
-
 #include "assert.h"
-
+#include "skipwrap.h"
 
 /* This code borrowed heavily from the previous version of log.  Here is the
    intro comment for that program: */
@@ -88,7 +76,7 @@ extern krb5_cc_ops krb5_mcc_ops;
 
 #define KLOGEXIT(code) rx_Finalize(); \
                        (exit(!!code))
-extern int CommandProc(struct cmd_syndesc *as, char *arock);
+static int CommandProc(struct cmd_syndesc *as, void *arock);
 
 static int zero_argc;
 static char **zero_argv;
@@ -120,7 +108,7 @@ main(int argc, char *argv[])
     zero_argc = argc;
     zero_argv = argv;
 
-    ts = cmd_CreateSyntax(NULL, CommandProc, 0,
+    ts = cmd_CreateSyntax(NULL, CommandProc, NULL,
 			  "obtain Kerberos authentication");
 
 #define aXFLAG 0
@@ -315,26 +303,32 @@ klog_prompter(krb5_context context,
 {
     krb5_error_code code;
     int i, type;
-#ifndef USING_HEIMDAL
+#if !defined(USING_HEIMDAL) && defined(HAVE_KRB5_GET_PROMPT_TYPES)
     krb5_prompt_type *types;
 #endif
     struct kp_arg *kparg = (struct kp_arg *) a;
     code = krb5_prompter_posix(context, a, name, banner, num_prompts, prompts);
     if (code) return code;
-#ifndef USING_HEIMDAL
+#if !defined(USING_HEIMDAL) && defined(HAVE_KRB5_GET_PROMPT_TYPES)
     if ((types = krb5_get_prompt_types(context)))
 #endif
     for (i = 0; i < num_prompts; ++i) {
-#ifdef USING_HEIMDAL
+#if !defined(USING_HEIMDAL) 
+#if defined(HAVE_KRB5_GET_PROMPT_TYPES)
+	type = types[i];
+#elif defined(HAVE_KRB5_PROMPT_TYPE)	
 	type = prompts[i].type;
 #else
-	type = types[i];
+	/* AIX 5.3 krb5_get_prompt_types is missing. Um... */
+	type = ((i == 1)&&(num_prompts == 2)) ? 
+	  KRB5_PROMPT_TYPE_NEW_PASSWORD_AGAIN : KRB5_PROMPT_TYPE_PASSWORD;
+#endif
+#else
+	type = prompts[i].type;
 #endif
 #if 0
-	printf ("i%d t%d <%.*s>\n", i,
-type,
-prompts[i].reply->length,
-prompts[i].reply->data);
+	printf ("i%d t%d <%.*s>\n", i, type, prompts[i].reply->length,
+		prompts[i].reply->data);
 #endif
 	switch(type) {
 	case KRB5_PROMPT_TYPE_PASSWORD:
@@ -347,18 +341,16 @@ prompts[i].reply->data);
     return 0;
 }
 
-int
-CommandProc(struct cmd_syndesc *as, char *arock)
+static int
+CommandProc(struct cmd_syndesc *as, void *arock)
 {
     krb5_principal princ = 0;
     char *cell, *pname, **hrealms, *service;
     char service_temp[MAXKTCREALMLEN + 20];
-    char realm[MAXKTCREALMLEN];
-    char lrealm[MAXKTCREALMLEN];	/* uppercase copy of local cellname */
     krb5_creds incred[1], mcred[1], *outcred = 0, *afscred;
     krb5_ccache cc = 0;
     krb5_get_init_creds_opt gic_opts[1];
-    char *tofree, *outname;
+    char *tofree = NULL, *outname;
     int code;
     char *what;
     int i, dosetpag, evil, noprdb, id;
@@ -379,11 +371,8 @@ CommandProc(struct cmd_syndesc *as, char *arock)
     static int Pipe = 0;	/* reading from a pipe */
     static int Silent = 0;	/* Don't want error messages */
 
-    int local;			/* explicit cell is same a local one */
     int writeTicketFile = 0;	/* write ticket file to /tmp */
 
-    char *reason;		/* string describing errors */
-
     service = 0;
     memset(incred, 0, sizeof *incred);
     /* blow away command line arguments */
@@ -437,7 +426,7 @@ CommandProc(struct cmd_syndesc *as, char *arock)
 	authtype |= env_afs_rxk5_default();
 #endif
 
-    cell = as->parms[aCELL].items ? cell = as->parms[aCELL].items->data : 0;
+    cell = as->parms[aCELL].items ? as->parms[aCELL].items->data : 0;
     if ((code = afsconf_GetCellInfo(tdir, cell, "afsprot", cellconfig))) {
 	if (cell)
 	    afs_com_err(rn, code, "Can't get cell information for '%s'", cell);
@@ -543,7 +532,7 @@ CommandProc(struct cmd_syndesc *as, char *arock)
 	    pass = passwd;
 	} else {
 	    pf = klog_prompter;
-	    pa = (char *)klog_arg;
+	    pa = klog_arg;
 	}
     }
 
@@ -604,11 +593,6 @@ CommandProc(struct cmd_syndesc *as, char *arock)
 		what = "getting default ccache";
 		code = krb5_cc_default(k5context, &cc);
 	    } else {
-#ifdef HAVE_KRB5_CC_REGISTER
-		what = "krb5_cc_register";
-		code = krb5_cc_register(k5context, &krb5_mcc_ops, FALSE);
-		if (code && code != KRB5_CC_TYPE_EXISTS) goto Failed;
-#endif
 		what = "krb5_cc_resolve";
 		code = krb5_cc_resolve(k5context, "MEMORY:core", &cc);
 		if (code) goto Failed;
